yakumo.keystone.v3

Package yakumo :: Package keystone :: Package v3 |
[hide private]
[frames] | no frames]

# Package v3

source code

Sub client class for Identity V3 API

Submodules | [hide private]
yakumo.keystone.v3.credential: Resource class and its manager for credentials in Identity V3 API yakumo.keystone.v3.domain: Resource class and its manager for domains in Identity V3 API yakumo.keystone.v3.endpoint: Resource class and its manager for endpoints in Identity V3 API yakumo.keystone.v3.group: Resource class and its manager for groups in Identity V3 API yakumo.keystone.v3.project: Resource class and its manager for projects in Identity V3 API yakumo.keystone.v3.region: Resource class and its manager for regions in Identity V3 API yakumo.keystone.v3.role: Resource class and its manager for roles in Identity V3 API yakumo.keystone.v3.service: Resource class and its manager for services in Identity V3 API yakumo.keystone.v3.user: Resource class and its manager for users in Identity V3 API

Classes | [hide private]
| Client

Variables | [hide private]
| __package__ = ``'``yakumo.keystone.v3``'``